@@ -37,7 +37,7 @@ pub struct Selection<'s> {
     pub is_exe: bool,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Clone, Copy)]
 pub enum SelInfo<'s> {
     None,
     One(Selection<'s>),
@@ -96,6 +96,16 @@ impl Selection<'_> {
 }
 
 impl<'a> SelInfo<'a> {
+    pub fn from_path(path: &'a Path) -> Self {
+        Self::One(
+            Selection {
+                stype: SelectionType::from(path),
+                line: 0,
+                path,
+                is_exe: false, // OK, I don't know
+            }
+        )
+    }
     pub fn count_paths(&self) -> usize {
         match self {
             SelInfo::None => 0,
@@ -124,6 +134,9 @@ impl<'a> SelInfo<'a> {
             _ => None,
         }
     }
+    pub fn one_path(self) -> Option<&'a Path> {
+        self.one_sel().map(|sel| sel.path)
+    }
     pub fn extension(&self) -> Option<&str> {
         match self {
             SelInfo::None => None,
