@@ -178,7 +178,7 @@ impl PanelState for FilesystemState {
     fn with_new_options(
         &mut self,
         _screen: Screen,
-        change_options: &dyn Fn(&mut TreeOptions),
+        change_options: &dyn Fn(&mut TreeOptions) -> &'static str,
         _in_new_panel: bool, // TODO open tree if true
         _con: &AppContext,
     ) -> CmdResult {
@@ -523,6 +523,7 @@ impl PanelState for FilesystemState {
                         con,
                         &dam,
                     ),
+                    None,
                     in_new_panel,
                 )
             }
@@ -540,9 +541,10 @@ impl PanelState for FilesystemState {
                     )
                 } else {
                     // we ask the app to focus the panel to the left
-                    CmdResult::HandleInApp(Internal::panel_left)
+                    CmdResult::HandleInApp(Internal::panel_left_no_open)
                 }
             }
+            Internal::panel_left_no_open => CmdResult::HandleInApp(Internal::panel_left_no_open),
             Internal::panel_right => {
                 let areas = &cc.panel.areas;
                 if areas.is_last() && areas.nb_pos < con.max_panels_count {
@@ -557,9 +559,10 @@ impl PanelState for FilesystemState {
                     )
                 } else {
                     // we ask the app to focus the panel to the right
-                    CmdResult::HandleInApp(Internal::panel_right)
+                    CmdResult::HandleInApp(Internal::panel_right_no_open)
                 }
             }
+            Internal::panel_right_no_open => CmdResult::HandleInApp(Internal::panel_right_no_open),
             Internal::page_down => {
                 if !self.try_scroll(ScrollCommand::Pages(1)) {
                     self.selection_idx = self.count() - 1;
