@@ -1,8 +1,8 @@
-#[macro_use] extern crate log;
-#[macro_use] extern crate cli_log;
+use cli_log::*;
 
 fn main() {
     init_cli_log!();
+    debug!("env::args(): {:#?}", std::env::args().collect::<Vec<String>>());
     match broot::cli::run() {
         Ok(Some(launchable)) => {
             debug!("launching {:#?}", launchable);
@@ -19,5 +19,6 @@ fn main() {
             eprintln!("{}", e);
         }
     };
+    log_mem(Level::Info);
     info!("bye");
 }
