@@ -2,16 +2,19 @@ use {
     crate::{
         app::AppContext,
     },
+    once_cell::sync::Lazy,
     std::path::Path,
     syntect::{
         easy::HighlightLines,
         parsing::SyntaxSet,
-        highlighting::ThemeSet,
+        highlighting::{Theme, ThemeSet},
     },
 };
 
 static SYNTAXES: &[u8] = include_bytes!("../../resources/syntect/syntaxes.bin");
 
+pub static SYNTAXER: Lazy<Syntaxer> = Lazy::new(Syntaxer::default);
+
 /// wrap heavy to initialize syntect things
 pub struct Syntaxer {
     pub syntax_set: SyntaxSet,
@@ -27,6 +30,12 @@ impl Default for Syntaxer {
 }
 
 impl Syntaxer {
+    pub fn available_themes(
+        &self
+    ) -> std::collections::btree_map::Keys<String, Theme> {
+        self.theme_set.themes.keys()
+    }
+
     pub fn highlighter_for<'s, 'p>(
         &'s self,
         path: &'p Path,
@@ -36,14 +45,8 @@ impl Syntaxer {
             .and_then(|e| e.to_str())
             .and_then(|ext| self.syntax_set.find_syntax_by_extension(ext))
             .map(|syntax| {
-                // some OK themes:
-                //  "base16-ocean.dark"
-                //  "Solarized (dark)"
-                //  "base16-eighties.dark"
-                //  "base16-mocha.dark"
-                let theme = con.syntax_theme.as_ref()
-                    .and_then(|key| self.theme_set.themes.get(key))
-                    .or_else(|| self.theme_set.themes.get("base16-mocha.dark"))
+                let theme = con.syntax_theme.unwrap_or_default();
+                let theme = self.theme_set.themes.get(theme.syntect_name())
                     .unwrap_or_else(|| self.theme_set.themes.iter().next().unwrap().1);
                 HighlightLines::new(syntax, theme)
             })
